@@ -2,7 +2,7 @@ from argparse import ArgumentParser
 
 __author__ = 'Kapustlo'
 
-__version__ = '2.0.0'
+__version__ = '2.3.0'
 
 parser: ArgumentParser = ArgumentParser(description='Build Django project')
 
@@ -16,7 +16,7 @@ parser.add_argument('--debug', dest='debug', action='store_true', required=False
 
 parser.add_argument('--hosts', dest='hosts', required=False, default='', help='List of comma separated ALLOWED_HOSTS values')
 
-parser.add_argument('--python', dest='python', required=False, default='python3', help='Python command')
+parser.add_argument('--python', dest='python', required=False, default=None, help='Python command. If not set, the Python used to run the program will be used')
 
 parser.add_argument('--migrate', dest='migrate', required=False, action='store_true', help='Apply default migrations after creation')
 
@@ -27,3 +27,5 @@ parser.add_argument('--commit', dest='commit', required=False, action='store_tru
 parser.add_argument('--commit-message', dest='commit_message', required=False, default='Initial commit', help='Initial commit name')
 
 parser.add_argument('--packages', dest='packages', nargs='+', help='Additional pip packages', required=False, default=[])
+
+parser.add_argument('--no-compile', dest='no_compile', action='store_true', required=False, help='pip: Do not compile Python source files to bytecode')
